@@ -5,7 +5,7 @@ use warnings;
 use Carp;
 use base 'Geo::GDAL::FFI::Object';
 
-our $VERSION = 0.1100;
+our $VERSION = '0.14';
 
 sub DESTROY {
     my $self = shift;
@@ -130,7 +130,8 @@ sub _make_overlay_methods {
                     my $schema = {
                         GeometryType => 'Unknown'
                     };
-                    $result = Geo::GDAL::FFI::GetDriver('Memory')->Create->CreateLayer($schema);
+                    state $mem_driver = Geo::GDAL::FFI::get_memory_driver();
+                    $result = Geo::GDAL::FFI::GetDriver($mem_driver)->Create->CreateLayer($schema);
                 }
                 my $o = 0;
                 for my $key (keys %{$args->{Options}}) {
